==> eam-wshub-proxyclient-11.5-3-sources.jar: net/datastream/schemas/mp_fields/CONTRACTTEMPLATEWOCRITERIAID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour CONTRACTTEMPLATEWOCRITERIAID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="CONTRACTTEMPLATEWOCRITERIAID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CONTRACTTEMPLATEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DEPARTMENTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WORKORDERTYPE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WORKORDERCLASSID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CONTRACTTEMPLATEWOCRITERIAID_Type", propOrder = {
    "contracttemplateid",
    "departmentid",
    "workordertype",
    "workorderclassid"
})
public class CONTRACTTEMPLATEWOCRITERIAID_Type {

    @XmlElement(name = "CONTRACTTEMPLATEID", required = true)
    protected CONTRACTTEMPLATEID_Type contracttemplateid;
    @XmlElement(name = "DEPARTMENTID", required = true)
    protected DEPARTMENTID_Type departmentid;
    @XmlElement(name = "WORKORDERTYPE", required = true)
    protected TYPE_Type workordertype;
    @XmlElement(name = "WORKORDERCLASSID", required = true)
    protected CLASSID_Type workorderclassid;

    /**
     * Obtient la valeur de la propriété contracttemplateid.
     * 
     * @return
     *     possible object is
     *     {@link CONTRACTTEMPLATEID_Type }
     *     
     */
    public CONTRACTTEMPLATEID_Type getCONTRACTTEMPLATEID() {
        return contracttemplateid;
    }

    /**
     * Définit la valeur de la propriété contracttemplateid.
     * 
     * @param value
     *     allowed object is
     *     {@link CONTRACTTEMPLATEID_Type }
     *     
     */
    public void setCONTRACTTEMPLATEID(CONTRACTTEMPLATEID_Type value) {
        this.contracttemplateid = value;
    }

    /**
     * Obtient la valeur de la propriété departmentid.
     * 
     * @return
     *     possible object is
     *     {@link DEPARTMENTID_Type }
     *     
     */
    public DEPARTMENTID_Type getDEPARTMENTID() {
        return departmentid;
    }

    /**
     * Définit la valeur de la propriété departmentid.
     * 
     * @param value
     *     allowed object is
     *     {@link DEPARTMENTID_Type }
     *     
     */
    public void setDEPARTMENTID(DEPARTMENTID_Type value) {
        this.departmentid = value;
    }

    /**
     * Obtient la valeur de la propriété workordertype.
     * 
     * @return
     *     possible object is
     *     {@link TYPE_Type }
     *     
     */
    public TYPE_Type getWORKORDERTYPE() {
        return workordertype;
    }

    /**
     * Définit la valeur de la propriété workordertype.
     * 
     * @param value
     *     allowed object is
     *     {@link TYPE_Type }
     *     
     */
    public void setWORKORDERTYPE(TYPE_Type value) {
        this.workordertype = value;
    }

    /**
     * Obtient la valeur de la propriété workorderclassid.
     * 
     * @return
     *     possible object is
     *     {@link CLASSID_Type }
     *     
     */
    public CLASSID_Type getWORKORDERCLASSID() {
        return workorderclassid;
    }

    /**
     * Définit la valeur de la propriété workorderclassid.
     * 
     * @param value
     *     allowed object is
     *     {@link CLASSID_Type }
     *     
     */
    public void setWORKORDERCLASSID(CLASSID_Type value) {
        this.workorderclassid = value;
    }

}

==> eam-wshub-proxyclient-12.1-0-sources.jar: net/datastream/schemas/mp_fields/CONTRACTTEMPLATEWOCRITERIAID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for CONTRACTTEMPLATEWOCRITERIAID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="CONTRACTTEMPLATEWOCRITERIAID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CONTRACTTEMPLATEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DEPARTMENTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WORKORDERTYPE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WORKORDERCLASSID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CONTRACTTEMPLATEWOCRITERIAID_Type", propOrder = {
    "contracttemplateid",
    "departmentid",
    "workordertype",
    "workorderclassid"
})
public class CONTRACTTEMPLATEWOCRITERIAID_Type {

    @XmlElement(name = "CONTRACTTEMPLATEID", required = true)
    protected CONTRACTTEMPLATEID_Type contracttemplateid;
    @XmlElement(name = "DEPARTMENTID", required = true)
    protected DEPARTMENTID_Type departmentid;
    @XmlElement(name = "WORKORDERTYPE", required = true)
    protected TYPE_Type workordertype;
    @XmlElement(name = "WORKORDERCLASSID", required = true)
    protected CLASSID_Type workorderclassid;

    /**
     * Gets the value of the contracttemplateid property.
     * 
     * @return
     *     possible object is
     *     {@link CONTRACTTEMPLATEID_Type }
     *     
     */
    public CONTRACTTEMPLATEID_Type getCONTRACTTEMPLATEID() {
        return contracttemplateid;
    }

    /**
     * Sets the value of the contracttemplateid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CONTRACTTEMPLATEID_Type }
     *     
     */
    public void setCONTRACTTEMPLATEID(CONTRACTTEMPLATEID_Type value) {
        this.contracttemplateid = value;
    }

    /**
     * Gets the value of the departmentid property.
     * 
     * @return
     *     possible object is
     *     {@link DEPARTMENTID_Type }
     *     
     */
    public DEPARTMENTID_Type getDEPARTMENTID() {
        return departmentid;
    }

    /**
     * Sets the value of the departmentid property.
     * 
     * @param value
     *     allowed object is
     *     {@link DEPARTMENTID_Type }
     *     
     */
    public void setDEPARTMENTID(DEPARTMENTID_Type value) {
        this.departmentid = value;
    }

    /**
     * Gets the value of the workordertype property.
     * 
     * @return
     *     possible object is
     *     {@link TYPE_Type }
     *     
     */
    public TYPE_Type getWORKORDERTYPE() {
        return workordertype;
    }

    /**
     * Sets the value of the workordertype property.
     * 
     * @param value
     *     allowed object is
     *     {@link TYPE_Type }
     *     
     */
    public void setWORKORDERTYPE(TYPE_Type value) {
        this.workordertype = value;
    }

    /**
     * Gets the value of the workorderclassid property.
     * 
     * @return
     *     possible object is
     *     {@link CLASSID_Type }
     *     
     */
    public CLASSID_Type getWORKORDERCLASSID() {
        return workorderclassid;
    }

    /**
     * Sets the value of the workorderclassid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CLASSID_Type }
     *     
     */
    public void setWORKORDERCLASSID(CLASSID_Type value) {
        this.workorderclassid = value;
    }

}
